import { Component } from "react";
import i18n from "../assets/i18n/i18n";
import PaymentForm from "./PaymentForm";
import PaymentResult from "./PaymentResult";
import { environment } from "../environment/conf";

class Payment extends Component {
  fields = null;
  state = {
    imageSrc: "cardExample",
    messages: [],
    sucess: false,
    resMessage: "",
  };

  componentDidMount = () => {
    if (this.fields == null) {
      this.tzlHostedFields();
    }
  };

  handleSubmit = (event) => {
    event.preventDefault();

    this.chargeCcData(event);
  };

  chargeCcData = (e) => {
    this.fields.charge(
      {
        terminal_name: environment.terminal_name,
        amount: e.target.amount.value,
        currency_code: environment.currency_code,
        response_language: environment.response_language,
      },
      (error, response) => {
        if (response) {
          this.parseResponse(response);
        }
        if (error) {
          if (error.messages !== null) {
            this.handleError(error);
          }
        }
      }
    );
  };

  handleError = (err) => {
    let tmpArray = [];
    err.messages.forEach((message) => {
      tmpArray.push(message.param);
    });
    this.setState({ messages: tmpArray, sucess: false });
  };

  parseResponse = (response) => {
    if (response.errors != null) {
      let tmpArray = [];
      response.errors.forEach((message) => {
        tmpArray.push(message.message);
      });
      const str = tmpArray.join();
      this.setState({ resMessage: str, sucess: false });
    } else {
      if (response.transaction_response.success === false) {
        this.setState({
          resMessage: response.transaction_response.error,
          sucess: true,
        });
      } else {
        this.setState({ sucess: true });
      }
    }
  };

  onCardNumberChanged = (result) => {
    if (result && result.cardType !== "unknown") {
      this.setState({ imageSrc: result.cardType });
    }
  };

  validityChange = (result) => {
    const tmpArray = this.state.messages.slice();
    if (result && result.field) {
      tmpArray.splice(result.field.index, 1);
    }
    this.setState({ messages: tmpArray });
  };

  tzlHostedFields = () => {
    const tzlFields = window.TzlaHostedFields.create({
      sandbox: false,

      fields: {
        card_holder_id_number: {
          selector: "#card_holder_id_number",
          placeholder: i18n.t("placeholder_card_holder_id"),
          tabindex: 2,
        },
        credit_card_number: {
          selector: "#credit_card_num",
          placeholder: i18n.t("placeholder_card_number"),
          tabindex: 1,
        },
        cvv: {
          selector: "#cvv",
          placeholder: i18n.t("placeholder_cvv"),
          tabindex: 4,
        },
        expiry: {
          selector: "#expiry",
          placeholder: i18n.t("placeholder_expiry"),
          tabindex: 3,
          version: "1",
        },
      },
    });
    tzlFields.onEvent("cardTypeChange", this.onCardNumberChanged);
    tzlFields.onEvent("blur", this.validityChange);

    this.fields = tzlFields;
  };

  render() {
    const { resMessage, imageSrc, sucess, messages } = this.state;
    if (resMessage !== "" || sucess) {
      return <PaymentResult msg={resMessage} success={sucess}></PaymentResult>;
    }

    return (
      <PaymentForm
        handleSubmit={this.handleSubmit}
        img={imageSrc}
        msg={messages}
      ></PaymentForm>
    );
  }
}

export default Payment;
